@@ -30,6 +30,7 @@ class CustomData(Data, DuplicationUnsafeSendableBase):
         # pylint: disable=W0511
         self.__id = id
         self.__values = args
+        self.is_mapping_identifier: bool = False
 
     @property
     def id(self) -> int:  # pylint: disable=C0103
@@ -56,3 +57,5 @@ class CustomData(Data, DuplicationUnsafeSendableBase):
             QueryParam(QueryParams.VALUES_COUNT_MAP, str_values),
             QueryParam(QueryParams.OVERWRITE, "true"),
         )
+        if self.is_mapping_identifier:
+            qb.append(QueryParam(QueryParams.MAPPING_IDENTIFIER, "true"))
