@@ -7,4 +7,6 @@ class RepeatTimer(Timer):
 
     def run(self):
         while not self.finished.wait(self.interval):
-            self.function(*self.args, **self.kwargs)
+            new_interval = self.function(*self.args, **self.kwargs)
+            if isinstance(new_interval, (float, int)):
+                self.interval = new_interval
